"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const _ = require("lodash");
const assert = require("assert");
const main = require("..");
const JsonPatch = require("fast-json-patch");
const RandomChanges = require("./RandomChanges");
const RandomObject = require("./RandomObject");
function performTest(createSpec, modifySpec) {
    const oldObj = RandomObject.create(createSpec);
    let newObj = _.cloneDeep(oldObj);
    RandomChanges.modify(newObj, modifySpec);
    it("create seed = " + createSpec.seed + ", change seed = " + modifySpec.seed, function () {
        const diff = main.diff(oldObj, newObj);
        const result = JsonPatch.applyPatch(oldObj, diff).newDocument;
        assert.deepEqual(result, newObj);
    });
}
function start() {
    describe("generated diff tests, n = [50, 100]", function () {
        for (let i = 1; i <= 20; i += 1) {
            performTest({
                nodeCountRange: {
                    min: 50,
                    max: 100
                },
                seed: "make" + i
            }, {
                seed: "modify" + i
            });
        }
    });
    describe("generated diff tests, n = [5000, 6000]", function () {
        for (let i = 1; i <= 5; i += 1) {
            performTest({
                nodeCountRange: {
                    min: 5000,
                    max: 6000
                },
                distribution: {
                    array: 1,
                    object: 1,
                    float: 5,
                    int: 5,
                    null: 2,
                    string: 10,
                    branchDone: 20
                },
                seed: "make" + i
            }, {
                seed: "modify" + i
            });
        }
    });
}
exports.start = start;
//# sourceMappingURL=GeneratedDiffTests.js.map