"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const assert = require("assert");
const main = require("..");
const JsonPatch = require("fast-json-patch");
function start() {
    describe("manual diff tests", function () {
        it("different arrays", () => {
            const oldObj = [1, 2, 3, 4, 5, 6, 7, 8, 9, 10];
            const newObj = [1, 2];
            const expected = [{
                    op: "replace",
                    path: "",
                    value: [1, 2]
                }];
            const result = main.diff(oldObj, newObj);
            assert.deepEqual(result, expected);
        });
        it("smart remove", () => {
            const oldObj = {
                a: [1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15],
                b: 1,
                c: 2,
                d: { a: 1, b: 2, c: 3, largeStr: "This is a pretty large string. It should be kept. Replacing this is not optimal" }
            };
            const newObj = {
                d: { a: 1, b: 2, c: 3, largeStr: "This is a pretty large string. It should be kept. Replacing this is not optimal" },
                test: [1, 2, 3, 4, 5]
            };
            const expected = [
                {
                    "op": "remove",
                    "path": "/c"
                },
                {
                    "op": "remove",
                    "path": "/b"
                },
                {
                    "op": "remove",
                    "path": "/a"
                },
                {
                    "op": "replace",
                    "path": "/test",
                    "value": [
                        1,
                        2,
                        3,
                        4,
                        5
                    ]
                }
            ];
            const result = main.diff(oldObj, newObj);
            assert.deepEqual(result, expected);
        });
        it("similar arrays", () => {
            const oldObj = [1, 2, 3, 4, 5, 6, 7, 8, 9, 10];
            const newObj = [1, 2, 3, 4, 5, 6, 7, 8, 9];
            const expected = [{
                    op: "remove",
                    path: "/9"
                }];
            const result = main.diff(oldObj, newObj);
            assert.deepEqual(result, expected);
        });
        it("different arrays", () => {
            const oldObj = [1, 2, 3, 4, 5, 6, 7, 8, 9, 10];
            const newObj = [1, 20, 30, 4, 50, 6, 7, 8, 9];
            const expected = [
                {
                    "op": "replace",
                    "path": "",
                    "value": [
                        1,
                        20,
                        30,
                        4,
                        50,
                        6,
                        7,
                        8,
                        9
                    ]
                }
            ];
            const result = main.diff(oldObj, newObj);
            assert.deepEqual(result, expected);
        });
        it("array in object", () => {
            const oldObj = {
                arr: [1, 2, 3, 4, 5, 6, 7, 8, 9, 10],
                keep: "This string should be kept. arr should be replaced."
            };
            const newObj = {
                arr: [1, 20, 30, 4, 50, 6, 7, 8, 9],
                keep: "This string should be kept. arr should be replaced."
            };
            const expected = [
                {
                    "op": "replace",
                    "path": "/arr",
                    "value": [
                        1,
                        20,
                        30,
                        4,
                        50,
                        6,
                        7,
                        8,
                        9
                    ]
                }
            ];
            const result = main.diff(oldObj, newObj);
            assert.deepEqual(result, expected);
        });
        it("complex objects", () => {
            const oldObj = {
                a: 123,
                b: {
                    c: [1, 2, 3, "test1", "test2 pretty long string", "test3", "test4"],
                    d: {
                        1: 11,
                        2: 22
                    },
                    f: "test",
                    g: { 0: 0, 1: 1 }
                }
            };
            const newObj = {
                a: 123,
                b: {
                    c: [1, 2, 3, "test1", "test2 pretty long string", "test3"],
                    d: {
                        1: 11,
                        2: 22,
                        3: 33
                    },
                    f: "test",
                    g: [0, 1]
                }
            };
            const expected = [{
                    op: "remove",
                    path: "/b/c/6"
                }, {
                    op: "replace",
                    path: "/b/d/3",
                    value: 33
                }, {
                    op: "replace",
                    path: "/b/g",
                    value: [0, 1]
                }];
            const result = main.diff(oldObj, newObj);
            assert.deepEqual(result, expected);
        });
        it("patch array", () => {
            const oldObj = [1, 2, 3, 4, 5, 6, 7, 8, 9];
            const newObj = [1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11];
            const diff = main.diff(oldObj, newObj);
            const result = JsonPatch.applyPatch(oldObj, diff).newDocument;
            assert.deepEqual(result, newObj);
        });
        it("patch small", () => {
            const oldObj = {
                a: "test",
                b: {
                    c: 100000,
                    d: 200000,
                    e: [100000, 200000, 400000],
                    f: {
                        g: [600000, 700000, 800000],
                        h: "hei på deg"
                    }
                }
            };
            const newObj = {
                a: "test2",
                b: {
                    c: 100000,
                    d: 200000,
                    e: [100000, 200000, 400000],
                    f: {
                        g: [600000, 700000, 800001],
                        h: "hei på deg"
                    }
                }
            };
            const diff = main.diff(oldObj, newObj);
            const result = JsonPatch.applyPatch(oldObj, diff).newDocument;
            assert.deepEqual(result, newObj);
        });
        it("patch medium", () => {
            const oldObj = {
                a: "test",
                b: {
                    c: 1,
                    d: 2,
                    e: [1, 2, 4],
                    f: {
                        g: [6, 7, 8],
                        h: "hei"
                    }
                },
                large1: {
                    arr1: [1, 2, 3, 4, 5, 6, 7, 8, 9],
                    arr2: [1, 2, 3, 4, 5, 6, 7, 8, 9],
                    arr3: [55, 66, 77, 888, 99, 9, 99, 4, true, false, "test"],
                    a: {
                        b: {
                            c: {
                                e: {
                                    f: {
                                        arr3: [55, 66, 77, 888, 99, 9, 99, 4, true, false, "test"],
                                        arr1: [100, 200]
                                    }
                                }
                            }
                        }
                    }
                },
                large2: {
                    arr1: [1, 2, 3, 4, 5, 6, 7, 8, 9],
                    arr2: [1, 2, 3, 4, 5, 6, 7, 8, 9],
                    arr3: [55, 66, 77, 888, 99, 9, 99, 4, true, false, "test"],
                    a: {
                        b: {
                            c: {
                                e: {
                                    f: {
                                        arr3: [55, 66, 77, 888, 99, 9, 99, 4, true, false, "test"],
                                        arr1: [100, 200]
                                    }
                                }
                            }
                        }
                    }
                }
            };
            const newObj = {
                a: "testNew",
                b: {
                    c: 1,
                    d: 2,
                    e: [1, 2, 4],
                    f: {
                        g: [6, 7, 8],
                        h: "hei"
                    },
                    g: "Dette er nytt"
                },
                large1: {
                    arr1: [1, 2, 3, 4, 5, 6, 7, 8, 9],
                    arr2: [1, 2, 3, 4, 5, 6, 7, 8, 9],
                    arr3: [55, 66, 77, 888, 99, 9, 99, 4, true, false, "test2"],
                    a: {
                        b: {
                            c: {
                                e: {
                                    f: {
                                        arr3: [55, 66, 77, 888, 99, 9, 99, 4, true, false, "test"],
                                        arr1: [100, 200, 300]
                                    }
                                }
                            }
                        }
                    }
                },
                large2: {
                    arr1: [1, 2, 3, 4, 5, 6, 7, 8, 9],
                    arr2: [1, 2, 3, 4, 5, 6, 7, 8, 9],
                    arr3: [55, 66, 77, 888, 99, 9, 99, 4, true, false, "test"],
                    a: {
                        b: {
                            c: {
                                e: {
                                    f: {
                                        arr3: [55, 66, 77, 888, 99, 9, 99, 4, true, false, "test"],
                                        arr1: [100, 200]
                                    }
                                }
                            }
                        }
                    }
                }
            };
            const diff = main.diff(oldObj, newObj);
            const result = JsonPatch.applyPatch(oldObj, diff).newDocument;
            assert.deepEqual(result, newObj);
        });
        it("patch large, n = 10000", () => {
            const oldObj = {
                a: "test",
                b: {
                    c: 1,
                    d: 2,
                    e: [1, 2, 4],
                    f: {
                        g: [6, 7, 8],
                        h: "hei"
                    }
                },
                large1: {
                    largeArr: (() => {
                        const res = [];
                        for (let i = 0; i < 10000; i += 1) {
                            res.push(i);
                        }
                        return res;
                    })()
                }
            };
            const newObj = {
                a: "testNew",
                b: {
                    c: 45,
                    d: 2,
                    e: [1, 2],
                    f: {
                        g: [6, 7, 7.5, 8],
                        h: true
                    }
                },
                large1: {
                    largeArr: (() => {
                        const res = [];
                        for (let i = 0; i < 9000; i += 1) {
                            res.push(i);
                        }
                        return res;
                    })()
                }
            };
            const diff = main.diff(oldObj, newObj);
            const result = JsonPatch.applyPatch(oldObj, diff).newDocument;
            assert.deepEqual(result, newObj);
        });
    });
}
exports.start = start;
//# sourceMappingURL=ManualDiffTests.js.map